# Changelog

## [0.3.3a1](https://github.com/OpenVoiceOS/ovos-core/tree/0.3.3a1) (2024-12-09)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/0.3.2...0.3.3a1)

**Merged pull requests:**

- fix: runtime requirements [\#628](https://github.com/OpenVoiceOS/ovos-core/pull/628) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
